==> homesitemaker-v0.4.5.tar.gz: homesitemaker/users.php <==
<!--

Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain

-->

<!-- NOMBRE ARCHIVO:            users.php                                           -->
<!-- AUTOR:                     Marcos Martinez Jimenez                             -->
<!-- SITE:                      HomeSite M.A.K.E.R                                  -->
<!-- INCLUDED ON:               index.php when control panel secction is selected   -->

<table border="0" width="90%" align="center">
<tr><td class="text6" colspan="4">&nbsp;</td></tr>
<tr><td class="text6" colspan="4"><?php  echo "".$$name_section."\n";?></td></tr>
<tr><td class="text6" colspan="4"><hr color="blue" size="2"></td></tr>

<?php
// Get the cookie user info.
if (isset($HTTP_COOKIE_VARS["id_session"])) {$id_session=$HTTP_COOKIE_VARS["id_session"];} else {$id_session="NULL";}
if (isset($_GET['id_user'])) {$id_user=$_GET['id_user'];} else {$id_user="$id_session[id_user]";}

// Get the user_secction to show in the next switch structrue
if (!isset($_GET['user_section'])) { $user_section=0; } else $user_section=$_GET['user_section'];
include ("includes/db_connect.php");
include ("includes/languages/".$LANGUAGE."/homesite-users.php");

//Get the current user level to show the properly actions
$current_user_query=mysql_query("SELECT level FROM users WHERE id_user='".$id_session[id_user]."'", $db);
$current_user=mysql_fetch_array ($current_user_query);


if ( $id_session[id_user] == $id_user )
   {
   // Get current user info from users database for edit current user
   $user_query=mysql_query("SELECT id_user, nick, password, user_photo_file, real_name, email, level FROM users WHERE id_user='".$id_session[id_user]."'", $db);
   } else if ($current_user["level"] == "99" ) 
             {
             // Get passed user info from users database for edit it (only if the current user is root user)
             $user_query=mysql_query("SELECT id_user, nick, password, user_photo_file, real_name, email, level FROM users WHERE id_user='$id_user'", $db);
             }


$user_result=mysql_fetch_array ($user_query);

if ($id_session[num] == $num && $id_session[num] != "NULL")
 {
 // Show the control panel options for the current user.
 echo "<tr><td class=\"link1-blue\" colspan=\"4\" align=\"center\">";
 echo "  <a href=\"index.php?top_tab=5&section_type=1&user_section=1&num=$num\">$TEXT001</a>";
 echo " | <a href=\"index.php?top_tab=5&section_type=1&user_section=2&num=$num\">$TEXT002</a>";
 if ($current_user["level"] == 99) 
  {
  # Only users with level > 50 can do these actions
  echo " | <a href=\"index.php?top_tab=5&section_type=1&user_section=3&num=$num&task=add\">$TEXT003</a>";
  echo " | <a href=\"index.php?top_tab=5&section_type=1&user_section=4&num=$num\">$TEXT004</a>";
  echo " | <a href=\"index.php?top_tab=5&section_type=1&user_section=5&num=$num\">$TEXT005</a>";
  }
  echo " | <a href=\"index.php?top_tab=5&section_type=1&user_section=6&num=$num\">$TEXT006</a>";
  echo "</td></tr>";
  echo "<tr><td class=\"text6\" colspan=\"4\"><hr color=\"blue\" size=\"1\"></td></tr>";
  echo "<tr><td class=\"text2\" colspan=\"4\"><br>";

  switch ($user_section) {
    case 0: // Control Panel. Display the control panel help
    include ("includes/control-panel/users/cp_help.php");
    break;
    case 1: // My Acount. Display the user profile of the current user
    include ("includes/control-panel/users/cp_my_acount.php");
    break;
    case 2: // Show Users. Display the users list
    include ("includes/control-panel/users/cp_user_list.php");
    break;
    case 3: // Add User Acount. Adds a new user account user
    include ("includes/control-panel/users/cp_add_user.php");
    break;
    case 4: // Delete User Acount. Delete user account if you have privilege
    include ("includes/control-panel/users/cp_delete_user.php");
    break;
    case 5: // Delete User Acount. Delete user account if you have privilege
    include ("includes/control-panel/users/cp_edit_user.php");
    break;
    case 6: // User Control Panel section. Display the User panel help
    include ("includes/control-panel/users/cp_user_help.php");
    break;
    }

  echo "<tr><td class=\"text6\" colspan=\"2\">&nbsp;</td></tr>";
  } else if ($user_section==3) 
            { // if unlogged user wants to add a unprivileged user the add user panel is showed
            include ("includes/control-panel/users/cp_add_user.php");
            } else {
                   // if the user cookie session is unexpected them show an alert message to the user
                   echo "<tr><td class=\"alert\"><center>";
                   echo "$TEXT007</center></td></tr>";
                  }



?>
</table>

==> homesitemaker-v0.4.7-1.tar.gz: homesitemaker/users.php <==
<!--

Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain

-->

<!-- NOMBRE ARCHIVO:            users.php                                           -->
<!-- AUTOR:                     Marcos Martinez Jimenez                             -->
<!-- SITE:                      HomeSite M.A.K.E.R                                  -->
<!-- INCLUDED ON:               index.php when control panel secction is selected   -->

<table border="0" width="90%" align="center">
<tr><td class="text6" colspan="4">&nbsp;</td></tr>
<tr><td class="text6" colspan="4"><?php  echo "".$$name_section."\n";?></td></tr>
<tr><td class="text6" colspan="4"><hr color=<?php echo "$TLC" ?> size=<?php echo "$TLS" ?> ></td></tr>

<?php
// Get the cookie user info.
if (isset($_COOKIE["id_session"])) {$id_session=$_COOKIE["id_session"];} else {$id_session="NULL";}
if (isset($_GET['id_user'])) {$id_user=$_GET['id_user'];} else {$id_user="$id_session[id_user]";}

// Get the user_secction to show in the next switch structrue
if (!isset($_GET['user_section'])) { $user_section=0; } else $user_section=$_GET['user_section'];
include ("includes/db_connect.php");
include ("includes/languages/".$LANGUAGE."/homesite-users.php");

//Get the current user level to show the properly actions
$current_user_query=mysql_query("SELECT level FROM users WHERE id_user='".$id_session[id_user]."'", $db);
$current_user=mysql_fetch_array ($current_user_query);


if ( $id_session[id_user] == $id_user )
   {
   // Get current user info from users database for edit current user
   $user_query=mysql_query("SELECT id_user, nick, password, user_photo_file, real_name, email, level FROM users WHERE id_user='".$id_session[id_user]."'", $db);
   } else if ($current_user["level"] == "99" ) 
             {
             // Get passed user info from users database for edit it (only if the current user is root user)
             $user_query=mysql_query("SELECT id_user, nick, password, user_photo_file, real_name, email, level FROM users WHERE id_user='$id_user'", $db);
             }


$user_result=mysql_fetch_array ($user_query);

if ($id_session[num] == $num && $id_session[num] != "NULL")
 {
 // Show the control panel options for the current user.
 echo "<tr><td colspan=4><table border=\"0\" width=\"100%\" align=\"center\"><tr>".
      "<td class=\"link1-blue\" align=\"center\">".
      "<a href=\"index.php?top_tab=5&section_type=1&user_section=1&num=$num\">".
      "<img border=0 src=\"images/skins/$ICONS/icons/png/$ICON_SIZE1/My_Account.png\" align=\"middle\"><br>".
      "$TEXT001</a></td>".
      "<td class=\"link1-blue\" align=\"center\">".
      "<a href=\"index.php?top_tab=5&section_type=1&user_section=2&num=$num\">".
      "<img border=0 src=\"images/skins/$ICONS/icons/png/$ICON_SIZE1/Show_Users.png\" align=\"middle\"><br>".
      "$TEXT002</a></td>";
 if ($current_user["level"] == 99) 
  {
  # Only users with level > 50 can do these actions
  echo "<td class=\"link1-blue\" align=\"center\">".
       "<a href=\"index.php?top_tab=5&section_type=1&user_section=3&num=$num&task=add\">".
       "<img border=0 src=\"images/skins/$ICONS/icons/png/$ICON_SIZE1/Add_Users.png\" align=\"middle\"><br>".
       "$TEXT003</a></td>".
       "<td class=\"link1-blue\" align=\"center\">".
       "<a href=\"index.php?top_tab=5&section_type=1&user_section=4&num=$num\">".
       "<img border=0 src=\"images/skins/$ICONS/icons/png/$ICON_SIZE1/Delete_Users.png\" align=\"middle\"><br>".
       "$TEXT004</a></td>".
       "<td class=\"link1-blue\" align=\"center\">".
       "<a href=\"index.php?top_tab=5&section_type=1&user_section=5&num=$num\">".
       "<img border=0 src=\"images/skins/$ICONS/icons/png/$ICON_SIZE1/Edit_Users.png\" align=\"middle\"><br>".
       "$TEXT005</a></td>";
  }
  echo "<td class=\"link1-blue\" align=\"center\">".
       "<a href=\"index.php?top_tab=5&section_type=1&user_section=6&num=$num\">".
       "<img border=0 src=\"images/skins/$ICONS/icons/png/$ICON_SIZE1/Help.png\" align=\"middle\"><br>".
       "$TEXT006</a></td>".
       //"</td></tr>".
       "</table></tr>".
       "<tr><td class=\"text6\" colspan=\"4\"><hr color=$BLC size=$BLS></td></tr>".
       "<tr><td class=\"text2\" colspan=\"4\"><br>";

  switch ($user_section) {
    case 0: // Control Panel. Display the control panel help
    include ("includes/control-panel/users/cp_help.php");
    break;
    case 1: // My Acount. Display the user profile of the current user
    include ("includes/control-panel/users/cp_my_acount.php");
    break;
    case 2: // Show Users. Display the users list
    include ("includes/control-panel/users/cp_user_list.php");
    break;
    case 3: // Add User Acount. Adds a new user account user
    include ("includes/control-panel/users/cp_add_user.php");
    break;
    case 4: // Delete User Acount. Delete user account if you have privilege
    include ("includes/control-panel/users/cp_delete_user.php");
    break;
    case 5: // Delete User Acount. Delete user account if you have privilege
    include ("includes/control-panel/users/cp_edit_user.php");
    break;
    case 6: // User Control Panel section. Display the User panel help
    include ("includes/control-panel/users/cp_user_help.php");
    break;
    }

  echo "<tr><td class=\"text6\" colspan=\"4\">&nbsp;</td></tr>";
  } else if ($user_section==3) 
            { // if unlogged user wants to add a unprivileged user the add user panel is showed
            include ("includes/control-panel/users/cp_add_user.php");
            } else {
                   // if the user cookie session is unexpected them show an alert message to the user
                   echo "<tr><td class=\"alert\"><center>";
                   echo "$TEXT007</center></td></tr>";
                  }



?>
</table>
